<?php
    /*
    Plugin Name: The Slide by SimpleReach
    Plugin URI: https://www.simplereach.com
    Description: After installation, you must click '<a href='options-general.php?page=SimpleReach-Slide'>Settings &rarr; SimpleReach Slide</a>' to turn on The Slide.
    Version: 0.6.0
    Author: SimpleReach
    Author URI: https://www.simplereach.com
    */

define('SRSLIDE_PLUGIN_VERSION', '0.6.0');
define('SRSLIDE_PLUGIN_DIR', dirname(__FILE__));
define('SRSLIDE_PLUGIN_URL', plugin_dir_url(__FILE__));
define('SRSLIDE_PLUGIN_SUPPORT_EMAIL', 'support@simplereach.com');
require_once('srslide_functions.php');
require_once('srslide_post.php');

/**
 * Insert The Slide by SimpleReach onto the post page
 *
 * @author Eric Lubow <elubow@simplereach.com>
 * @param String $content the_content() output
 * @return String The content and The Slide code (if applicable)
 */
function srslide_insert_slide($content)
{
    global $post;
    $post_id = $post;
    if (is_object($post_id)) {
        $post_id = $post_id->ID;
    }

    // Return the content on anything other than post pages
    $recommend_pages = get_option('srslide_use_pages');
    if (!$recommend_pages == true) {
        $recommend_pages = false;
    }
    if (!is_singular() || is_attachment()) { // Don't show slide on attachment pages
        return $content;
    }
    if (is_page() && $recommend_pages == false) {
        return $content;
    }

    // If the post isn't published yet, we don't need a slide
    if ($post->post_status != 'publish') {
        return $content;
    }

    $sr_pub_id = get_option('srslide_pid');

    // There is no point in continuing without a PID, so stop
    if (strlen($sr_pub_id) != 24) {
        return $content;
    }

    $title = get_sr_post_title($post);
    $tags = get_sr_post_tags($post);
    $icon = get_sr_post_article_icon($post);
    $disable_on_post = get_post_meta($post_id,'_srslide_disable_on_post',true);
    $published_date = $post->post_date_gmt;
    $canonical_url = urlencode(get_permalink($post->ID));
    $slide_logo = get_option('srslide_show_logo') ? 'true' : 'false';
    $header_text = get_option('srslide_header_text');

    $channels = get_channels($post);

    // Ensure The Slide is enabled when it's supposed to be
    if (!empty($disable_on_post)) {
        $disable_on_post = 'false';
        return $content;
    }

    if ($icon) {
        $iconTag = 'icon: "'.$icon.'",';
    }

    $SRSLIDE_PLUGIN_VERSION = SRSLIDE_PLUGIN_VERSION;

// Get the JS ready to go
// Grab offset and strip off any non-digits
$offset = preg_replace('/\D/', '', get_option('srslide_style_element_bottom'));
$offsetTag = (!empty($offset)) ? 'offset: \'' . $offset . '\',' : '';

$use_css_url = '\'document.location.protocol + \'//d8rk54i4mohrb.cloudfront.net/css/p/'.$sr_pub_id.'.css\'';
$css_option = get_option('srslide_css_option');
if ($css_option == 2) {
	$css_url = get_option('srslide_css_url');
	if (function_exists('filter_var')) {
		if (filter_var($css_url,FILTER_VALIDATE_URL)) {
			$use_css_url = "'".$css_url."'";
		}
	}
	else {
		$use_css_url = "'".str_replace(array('"',"'",'<'),array(''),$css_url)."'";
	}
}



	$rv = '<!-- SimpleReach Slide Plugin Version: '.$SRSLIDE_PLUGIN_VERSION.' -->'."\n";
	$rv .= '<script type=\'text/javascript\' id=\'simplereach-slide-tag\'>'."\n";
	$rv .= '    __spr_config = {'."\n";
	$rv .= '      pid: \''.$sr_pub_id.'\','."\n";
	$rv .= '      title: \''.$title.'\','."\n";
	$rv .= '      ckw: \''.$tags.'\','."\n";
	$rv .= '      chan: \''.$channels.'\','."\n";
	if (!empty($offsetTag)) {
		$rv .= '      '.$offsetTag.''."\n";
	}
	if (!empty($iconTag)) {
		$rv .= '      '.$iconTag.''."\n";
	}
	if ($post_end_date = get_post_meta($post_id,'_srslide_post_end_date',true)) {
		$end_date_pattern = '/(\d+)\-(\d+)\-(\d+)\s+(\d+):(\d+):(\d+)/';
		if (preg_match($end_date_pattern,$post_end_date)) {
			$rv .= '      end: \''.$post_end_date.'\','."\n";
		}
	}
	$rv .= '      no_slide: \''.$disable_on_post.'\','."\n";
	$rv .= '      slide_logo: '.$slide_logo.','."\n";
	$rv .= '      pub: \''.$published_date.'\','."\n";
	$rv .= '      url: \''.$canonical_url.'\','."\n";
	$rv .= '      header: \''.$header_text.'\''."\n";
	$rv .= '    };'."\n";
	$rv .= '    var content = document.getElementById(\'simplereach-slide-tag\').parentNode, loc;'."\n";
	$rv .= '    if (content.className){ loc = \'.\' + content.className; }'."\n";
	$rv .= '    if (content.id){ loc = \'#\' + content.id; }'."\n";
	$rv .= '    __spr_config.loc = loc || content;'."\n";
	$rv .= '    (function(){'."\n";
	$rv .= '    var s = document.createElement(\'script\');'."\n";
	$rv .= '      s.async = true;'."\n";
	$rv .= '      s.type = \'text/javascript\';'."\n";
	$rv .= '      s.src = document.location.protocol + \'//d8rk54i4mohrb.cloudfront.net/js/slide.js\';'."\n";
	$rv .= '      __spr_config.css = '.$use_css_url.';'."\n";
	$rv .= '      var tg = document.getElementsByTagName(\'head\')[0];'."\n";
	$rv .= '      if (!tg) {tg = document.getElementsByTagName(\'body\')[0];}'."\n";
	$rv .= '      if (tg) {tg.appendChild(s);}'."\n";
	$rv .= '    })();'."\n";
	$rv .= '</script>'."\n";

    return $content . $rv;
}

/**
 * srslide_admin_init
 * Inititalize admin / register and load srslide.css
 *
 * @access public
 * @return void
 */
function srslide_admin_init()
{
    wp_register_style('srslide.css', SRSLIDE_PLUGIN_URL . 'srslide.css');
    wp_enqueue_style('srslide.css');
}

/**
 * Add the SimpleReach admin section
 *
 * @author Eric Lubow <elubow@simplereach.com>
 * @param None
 * @return None
 */
function srslide_admin()
{
    include_once('srslide_admin.php');
}

/**
 * Add the SimpleReach admin options to the post CRUD page
 *
 * @author Eric Lubow <elubow@simplereach.com>
 * @param None
 * @return None
 */
function srslide_admin_actions()
{
    include_once('srslide_post.php');
    add_options_page("SimpleReach Slide", "SimpleReach Slide", 'manage_options', "SimpleReach-Slide", "srslide_admin");
}

/**
 * Add the settings link to the plugin listings menu page
 *
 * @author Eric Lubow <elubow@simplereach.com>
 * @param None
 * @return None
 */
function srslide_plugin_action_links($links,$file)
{
    if ( $file == plugin_basename( dirname(__FILE__).'/srslide.php' ) ) {
        $links[] = '<a href="options-general.php?page=SimpleReach-Slide" class="bold">'.__('Settings').'</a>';
    }
    return $links;
}

/**
 * Setup the locales for i18n
 *
 * @author Malaney Hill <engineering@simplereach.com>
 * @param None
 * @return None
 */
function srslide_textdomain()
{
        $locale        = apply_filters( 'srslide_locale', get_locale() );
        $mofile        = sprintf( 'srslide-%s.mo', $locale );
        $mofile_local  = SRSLIDE_PLUGIN_DIR . '/lang/' . $mofile;

        if (file_exists($mofile_local)) {
                return load_textdomain( 'srslide', $mofile_local );
        } else {
                return false;
	}
}

/**
 * Run the appropriate actions on hooks
 *
 * @author Malaney Hill <engineering@simplereach.com>
 * @param None
 * @return None
 */
function srslide_loaded()
{
	do_action('srslide_loaded');
}

if (is_admin()) {
    add_action('admin_init', 'srslide_admin_init');
}
add_filter('the_content', 'srslide_insert_slide');
add_filter('plugin_action_links', 'srslide_plugin_action_links', 10, 2);
add_action('admin_menu','srslide_admin_actions');
add_action('add_meta_boxes','srslide_post_meta_box');
add_action('save_post','srslide_post_save_data');
add_action('edit_post','srslide_post_save_data');
add_action('srslide_loaded', 'srslide_textdomain', 2);
add_action('plugins_loaded', 'srslide_loaded', 20);
?>
